/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: a_finished.h 643 2005-11-05 01:16:14Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQHBCI_A_FINISHED_H
#define AQHBCI_A_FINISHED_H

#include "waction.h"
#include "winfo.h"



class ActionFinished: public WizardAction {
public:
  ActionFinished(Wizard *w);
  virtual ~ActionFinished();
};


#endif
